@@ -21,7 +21,7 @@
  *
  */
 
-#if !defined(__COGL_H_INSIDE__) && !defined(CLUTTER_COMPILATION)
+#if !defined(__COGL_H_INSIDE__) && !defined(COGL_COMPILATION)
 #error "Only <cogl/cogl.h> can be included directly."
 #endif
 
@@ -30,8 +30,6 @@
 
 #include <glib.h>
 
-#include <GL/gl.h>
-
 G_BEGIN_DECLS
 
 
@@ -51,15 +49,11 @@ G_BEGIN_DECLS
 #define COGL_HAS_XLIB 1
 #define COGL_HAS_XLIB_SUPPORT 1
 
-#ifdef COGL_HAS_EGL_SUPPORT
+#define COGL_VERSION_MAJOR_INTERNAL 1
+#define COGL_VERSION_MINOR_INTERNAL 12
+#define COGL_VERSION_MICRO_INTERNAL 2
+#define COGL_VERSION_STRING_INTERNAL "1.12.2"
 
-#define NativeDisplayType EGLNativeDisplayType
-#define NativeWindowType EGLNativeWindowType
-#endif
-
-#ifndef GL_OES_EGL_image
-#define GLeglImageOES void *
-#endif
 G_END_DECLS
 
 #endif
